==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/world/gen/ChunkGeneratorSettingsInit.java <==
package cc.thonly.reverie_dreams.world.gen;

import cc.thonly.reverie_dreams.Touhou;
import cc.thonly.reverie_dreams.block.ModBlocks;
import java.util.ArrayList;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2960;
import net.minecraft.class_5284;
import net.minecraft.class_5309;
import net.minecraft.class_5321;
import net.minecraft.class_5843;
import net.minecraft.class_6686;
import net.minecraft.class_6910;
import net.minecraft.class_6916;
import net.minecraft.class_6953;
import net.minecraft.class_6954;
import net.minecraft.class_7871;
import net.minecraft.class_7891;
import net.minecraft.class_7924;

public class ChunkGeneratorSettingsInit {
    public static final class_5321<class_5284> MOON = getOrCreateRegistryKey("moon");

    public static void bootstrap(class_7891<class_5284> context) {
        class_7871<class_6910> densityFunctionLookup = context.method_46799(class_7924.field_41240);
        class_5284 moon = new class_5284(
                class_5309.method_32994(0, 128, 2, 1),
                ModBlocks.MOON_STONE.block().method_9564(),
                class_2246.field_10124.method_9564(),
                new class_6953(
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6954.method_42365(class_6916.method_40480(-0.703125), 0, 128, 80, 64, -0.1, 0, 24, 0.1),
                        class_6954.method_41207(method_50924(class_6954.method_41116(densityFunctionLookup, class_6954.field_37126))),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479()
                ),
                class_6686.method_39050(
                        class_6686.method_39049(class_6686.method_39472(
                                        "bedrock_floor",
                                        class_5843.method_33840(), class_5843.method_33846(5)),
                                block(class_2246.field_9987)
                        ),
                        block(ModBlocks.MOON_STONE.block())),
                new ArrayList<>(),
                10,
                false,
                false,
                true,
                false

        );
        context.method_46838(MOON, moon);
    }

    private static class_6910 method_50924(class_6910 densityFunction) {
        return class_6954.method_42365(densityFunction, 0, 128, 80, 64, -0.1, 0, 24, 0.1);
    }

    private static class_6686.class_6708 block(class_2248 block) {
        return class_6686.method_39047(block.method_9564());
    }

    public static void init() {

    }

    public static class_5321<class_5284> getOrCreateRegistryKey(String name) {
        return class_5321.method_29179(class_7924.field_41243, class_2960.method_60655(Touhou.MOD_ID, name));
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/world/gen/ChunkGeneratorSettingsInit.java <==
package cc.thonly.reverie_dreams.world.gen;

import cc.thonly.reverie_dreams.ReverieDreams;
import cc.thonly.reverie_dreams.registry.content.block.RDBlocks;
import java.util.ArrayList;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2960;
import net.minecraft.class_5284;
import net.minecraft.class_5309;
import net.minecraft.class_5321;
import net.minecraft.class_5843;
import net.minecraft.class_6686;
import net.minecraft.class_6910;
import net.minecraft.class_6916;
import net.minecraft.class_6953;
import net.minecraft.class_6954;
import net.minecraft.class_7871;
import net.minecraft.class_7891;
import net.minecraft.class_7924;

public class ChunkGeneratorSettingsInit {
    public static final class_5321<class_5284> MOON = getOrCreateRegistryKey("moon");

    public static void bootstrap(class_7891<class_5284> context) {
        class_7871<class_6910> densityFunctionLookup = context.method_46799(class_7924.field_41240);
        class_5284 moon = new class_5284(
                class_5309.method_32994(0, 128, 2, 1),
                RDBlocks.MOON_STONE.block().method_9564(),
                class_2246.field_10124.method_9564(),
                new class_6953(
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6954.method_42365(class_6916.method_40480(-0.703125), 0, 128, 80, 64, -0.1, 0, 24, 0.1),
                        class_6954.method_41207(method_50924(class_6954.method_41116(densityFunctionLookup, class_6954.field_37126))),
                        class_6916.method_40479(),
                        class_6916.method_40479(),
                        class_6916.method_40479()
                ),
                class_6686.method_39050(
                        class_6686.method_39049(class_6686.method_39472(
                                        "bedrock_floor",
                                        class_5843.method_33840(), class_5843.method_33846(5)),
                                block(class_2246.field_9987)
                        ),
                        block(RDBlocks.MOON_STONE.block())),
                new ArrayList<>(),
                10,
                false,
                false,
                true,
                false

        );
        context.method_46838(MOON, moon);
    }

    private static class_6910 method_50924(class_6910 densityFunction) {
        return class_6954.method_42365(densityFunction, 0, 128, 80, 64, -0.1, 0, 24, 0.1);
    }

    private static class_6686.class_6708 block(class_2248 block) {
        return class_6686.method_39047(block.method_9564());
    }

    public static void init() {

    }

    public static class_5321<class_5284> getOrCreateRegistryKey(String name) {
        return class_5321.method_29179(class_7924.field_41243, class_2960.method_60655(ReverieDreams.MOD_ID, name));
    }
}
